/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

package de.intevation.gnv.artifacts;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.ArtifactFactory;
import de.intevation.artifacts.CallContext;

import java.io.FileOutputStream;

import org.apache.log4j.Logger;

import org.w3c.dom.Document;

/**
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 *
 */
public class MeshHorizontalCrossSectionTestCase extends
                                               GNVArtifactsTestCaseBase {

    private static Logger log = Logger.getLogger(MeshHorizontalCrossSectionTestCase.class);

    /**
     * Constructor
     */
    public MeshHorizontalCrossSectionTestCase() {
    }

    /**
     * Constructor
     * @param name
     */
    public MeshHorizontalCrossSectionTestCase(String name) {
        super(name);
    }

    /**
     * @see de.intevation.gnv.artifacts.GNVArtifactsTestCaseBase#testArtifact()
     */
    @Override
    public void testArtifact() {
        try {
            log.debug("GNVArtifactsTestCase.testHorizontalCrossSectionMeshArtifact");
            String artefactName = "fis_modeldata";
            ArtifactFactory artifactFactory = this
                    .getArtifactFactory(artefactName);
            assertNotNull(artifactFactory);
            log.debug("HorizontalCrossSectionMesh-ArtifactFactory is available");

            Artifact artifact = createArtifact(artifactFactory);

            CallContext cc = createCallContext(artifactFactory);
            Document describeDocument = this.readDocument("src/test/ressources/horizontalcrosssection_mesh/horizontalcrosssection_describe.xml");
            int steps = 8;

            for (int i = 1; i <= steps; i++){
                this.doNextStep(
                            artifact,
                            cc,
                            "src/test/ressources/horizontalcrosssection_mesh/" +
                            "horizontalcrosssection_step_0"+i+"_feed.xml",
                            "src/test/ressources/horizontalcrosssection_mesh/" +
                            "horizontalcrosssection_step_0"+i+"_advance.xml",
                            describeDocument);
            }

            Document outputData = artifact.describe(describeDocument,cc);
            FileOutputStream fos = null;
            FileOutputStream fos2 = null;
            try {
                fos = new FileOutputStream(
                        "src/test/results/horizontalcrosssection_mesh"
                                + System.currentTimeMillis() + ".zip");
                fos2 = new FileOutputStream(
                        "src/test/results/horizontalcrosssection_mesh"
                                + System.currentTimeMillis() + ".txt");
                artifact.out(this.readDocument("src/test/ressources/" +
                                               "horizontalcrosssection_mesh/" +
                                               "horizontalcrosssection_step_0"+steps+"_out_zip.xml"),
                              fos, cc);
                artifact.out(this.readDocument("src/test/ressources/" +
                                               "horizontalcrosssection_mesh/" +
                                               "horizontalcrosssection_step_0"+steps+"_out_wms.xml"),
                             fos2,cc);
            } catch (Exception e) {
                log.error(e, e);
                fail();
            } finally {
                try {
                    fos.flush();
                    fos.close();
                    fos2.flush();
                    fos2.close();
                } catch (Exception e) {
                    log.error(e, e);
                }
            }
        } catch (Exception e) {
            log.error(e, e);
            fail();
        }
    }

}
